@@ -1,9 +1,27 @@
 #ifndef _APPLEUSBAUDIOLEVELCONTROL_H
 #define _APPLEUSBAUDIOLEVELCONTROL_H
 
-#include <IOKit/audio/IOAudioLevelControl.h>
+#include <sys/cdefs.h>
+
+__BEGIN_DECLS
+#include <kern/thread_call.h>
+__END_DECLS
+
+#include <libkern/OSByteOrder.h>
+
+#include <IOKit/IOLib.h>
+#include <IOKit/IOPlatformExpert.h>
+
+#include <IOKit/usb/USB.h>
 #include <IOKit/usb/IOUSBInterface.h>
 
+#include <IOKit/audio/IOAudioLevelControl.h>
+#include <IOKit/audio/IOAudioTypes.h>
+#include <IOKit/audio/IOAudioDefines.h>
+
+#include "AppleUSBAudioCommon.h"
+#include "USBAudioObject.h"
+
 class AppleUSBAudioDevice;
 typedef struct call_entry *thread_call_t;
 
