@@ -71,7 +71,7 @@ IOReturn AppleUSBTrinityAudioDevice::xdfpSetMem (UInt8 * buf, UInt16 length, UIn
     IOReturn			result;
     
     result = kIOReturnError;
-    FailWithAction (!controlInterface, debugIOLog ("AppleUSBTrinityAudioDevice::xdfpSetMem () - Error - no USB interface\n"), Exit);
+    FailWithAction (!mControlInterface, debugIOLog ("AppleUSBTrinityAudioDevice::xdfpSetMem () - Error - no USB interface\n"), Exit);
 
     devReq.bmRequestType = USBmakebmRequestType (kUSBOut, kUSBVendor, kUSBDevice);
     devReq.bRequest = kMicronasSetMemReq;
@@ -80,7 +80,7 @@ IOReturn AppleUSBTrinityAudioDevice::xdfpSetMem (UInt8 * buf, UInt16 length, UIn
     devReq.wLength = length;
     devReq.pData = buf;
 
-    result = controlInterface->DeviceRequest (&devReq);
+    result = mControlInterface->DeviceRequest (&devReq);
 
 Exit:
     return result;
@@ -91,7 +91,7 @@ IOReturn AppleUSBTrinityAudioDevice::xdfpGetMem (UInt8 * buf, UInt16 length, UIn
     IOReturn			result;
     
     result = kIOReturnError;
-    FailWithAction (!controlInterface, debugIOLog ("AppleUSBTrinityAudioDevice::xdfpGetMem () - Error - no USB interface\n"), Exit);
+    FailWithAction (!mControlInterface, debugIOLog ("AppleUSBTrinityAudioDevice::xdfpGetMem () - Error - no USB interface\n"), Exit);
 
     devReq.bmRequestType = USBmakebmRequestType (kUSBIn, kUSBVendor, kUSBDevice);
     devReq.bRequest = kMicronasGetMemReq;
@@ -100,7 +100,7 @@ IOReturn AppleUSBTrinityAudioDevice::xdfpGetMem (UInt8 * buf, UInt16 length, UIn
     devReq.wLength = length;
     devReq.pData = buf;
 
-    result = controlInterface->DeviceRequest (&devReq);
+    result = mControlInterface->DeviceRequest (&devReq);
 
 Exit:
     return result;
@@ -135,9 +135,9 @@ SInt32 *AppleUSBTrinityAudioDevice::getProperEQSettings () {
 
     settings = NULL;
     availablePower = 500;
-    FailIf (!controlInterface, Exit);
+    FailIf (!mControlInterface, Exit);
 
-    device = controlInterface->GetDevice ();
+    device = mControlInterface->GetDevice ();
     FailIf (!device, Exit);
 
 	plane = IORegistryEntry::getPlane (kIOUSBPlane);		// As per 2679853
@@ -224,7 +224,7 @@ bool AppleUSBTrinityAudioDevice::start (IOService * provider) {
 	downloadPlugin ();
 	enablePlugin ();
 
-	device = controlInterface->GetDevice ();
+	device = mControlInterface->GetDevice ();
 	FailIf (NULL == device, Exit);
 
 	result = TRUE;
@@ -265,7 +265,7 @@ void AppleUSBTrinityAudioDevice::scheduleEQDownloadRetry (void) {
 void AppleUSBTrinityAudioDevice::attemptEQDownload (void) {
     debugIOLog ("AppleUSBTrinityAudioDevice::attemptEQDownload () - eqRetryCount = %d", eqRetryCount);
 
-	FailIf (NULL == controlInterface, Exit);
+	FailIf (NULL == mControlInterface, Exit);
 	if (downloadEQ () != kIOReturnSuccess) {
 		if (++eqRetryCount < MAX_EQ_DOWNLOAD_RETRIES) {
 			scheduleEQDownloadRetry ();
