@@ -218,22 +218,26 @@ UInt8 USBAudioConfigObject::FindAltInterfaceWithSettings (UInt8 interfaceNum, UI
 	theAltInterface = 255;
 	found = FALSE;
 	while (!found && potentialAltInterface != 255) {
-		potentialAltInterface = FindNextAltInterfaceWithNumChannels (interfaceNum, potentialAltInterface, numChannels);
-		FailIf (255 == potentialAltInterface, Exit);
-		if (potentialAltInterface == FindNextAltInterfaceWithSampleSize (interfaceNum, potentialAltInterface, sampleSize)) {
+		if ((GetFormat (interfaceNum, potentialAltInterface) & 0x0FFF) != 0) {	// Make sure it's not an undefined format
+			potentialAltInterface = FindNextAltInterfaceWithNumChannels (interfaceNum, potentialAltInterface, numChannels);
 			FailIf (255 == potentialAltInterface, Exit);
-			if (0 != sampleRate) {
-				// they want a specific sample rate on this interface
-				if (potentialAltInterface == FindNextAltInterfaceWithSampleRate (interfaceNum, potentialAltInterface, sampleRate)) {
+			if (potentialAltInterface == FindNextAltInterfaceWithSampleSize (interfaceNum, potentialAltInterface, sampleSize)) {
+				FailIf (255 == potentialAltInterface, Exit);
+				if (0 != sampleRate) {
+					// they want a specific sample rate on this interface
+					if (potentialAltInterface == FindNextAltInterfaceWithSampleRate (interfaceNum, potentialAltInterface, sampleRate)) {
+						found = TRUE;
+						theAltInterface = potentialAltInterface;
+					} else {
+						potentialAltInterface++;
+					}
+				} else {
+					// they don't care about the sample rate
 					found = TRUE;
 					theAltInterface = potentialAltInterface;
-				} else {
-					potentialAltInterface++;
 				}
 			} else {
-				// they don't care about the sample rate
-				found = TRUE;
-				theAltInterface = potentialAltInterface;
+				potentialAltInterface++;
 			}
 		} else {
 			potentialAltInterface++;
